pub struct Tx3Client { /* private fields */ }Expand description
High-level client that ties a protocol to a TRP client.
Implementations
Sourceimpl Tx3Client
impl Tx3Client
Sourcepub fn with_profile(self, profile: impl Into<String>) -> Self
pub fn with_profile(self, profile: impl Into<String>) -> Self
Sets the profile for all invocations created by this client.
This profile is applied to every invocation created by the client.
Sourcepub fn with_party(self, name: impl Into<String>, party: Party) -> Self
pub fn with_party(self, name: impl Into<String>, party: Party) -> Self
Attaches a party definition to this client.
Sourcepub fn with_parties<I, K>(self, parties: I) -> Self
pub fn with_parties<I, K>(self, parties: I) -> Self
Attaches multiple party definitions to this client.