pub struct TxWitness {
pub key: BytesEnvelope,
pub signature: BytesEnvelope,
pub witness_type: WitnessType,
}Expand description
A cryptographic witness (signature) for a transaction.
Witnesses provide the proof that a transaction has been authorized by the holder of a private key. Each witness includes the public key, signature, and the type of witness.
Fields
key- The public key bytessignature- The cryptographic signaturewitness_type- The type of witness (currently only VKey supported)
Fields
key: BytesEnvelopeThe public key bytes.
signature: BytesEnvelopeThe cryptographic signature.
witness_type: WitnessTypeThe type of witness.